<!-- generated by dotrepo 1.0.0 | schema: dotrepo/v0.1 | source: sha256:5a8785f17614efd144743c83facac89665cad24feec47c1eee386d9242a04a12 -->
# Security

Please report vulnerabilities to https://github.com/maxwellsantoro/ries-rs/security/advisories/new.
